@@ -4,6 +4,6 @@ from .tagging import GenericTaggingClient, FashionTaggingClient
 from .colors import DominantColorProductClient, DominantColorGenericClient
 from .visual import VisualSearchClient
 from .detection import DetectionClient
-from .search import SimilarityPhotosClient, SimilarityProductsClient
+from .search import SimilarityPhotosClient, SimilarityProductsClient, SimilarityFashionClient, SimilarityCustomClient
 from .flows import FlowsClient
 from .exceptions import XimilarClientException
